@@ -31,7 +31,6 @@ static void		 set_level (guint level);
 static int gamewon;
 static gint process_time_id = 0;
 
-static void		 process_ok(void);
 static void		 process_time(void);
 static void		 game_won(void);
 static void		 destroy_board(void);
@@ -61,10 +60,10 @@ static void		 destroy_board(void);
 #define HORIZONTAL_SEPARATION 20
 #define VERTICAL_SEPARATION 20
 
-static char* background_images[] = {"gcompris/animals/tiger1_by_Ralf_Schmode",
-				    "gcompris/animals/tigerdrink001.jpg",
-				    "gcompris/animals/tigercub003.jpg",
-				    "gcompris/animals/tigerplay001.jpg"};
+static char* background_images[] = {"opt/animals/tiger1_by_Ralf_Schmode",
+				    "opt/animals/tigerdrink001.jpg",
+				    "opt/animals/tigercub003.jpg",
+				    "opt/animals/tigerplay001.jpg"};
 static const char  oper_values[] = {'+', '-', 'x', ':', '='};
 static const char *oper_images[] = {"plus", "minus", "by", "div", "equal"};
 static const int   num_values[] = {1,2,3,4,5,6,7,8,9,10,25,50,100};
@@ -149,7 +148,7 @@ static BoardPlugin menu_bp =
     end_board,
     is_our_board,
     NULL,
-    process_ok,
+    NULL,
     set_level,
     NULL,
     NULL,
@@ -202,7 +201,7 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
     button_pixmap = gc_pixmap_load(str);
     g_free(str);
 
-    gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),"gcompris/animals/tiger1_by_Ralf_Schmode.jpg");
+    gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),"opt/animals/tiger1_by_Ralf_Schmode.jpg");
     gcomprisBoard->level=1;
     gcomprisBoard->maxlevel=NUMBER_OF_LEVELS;
     gcomprisBoard->sublevel=1;
@@ -211,7 +210,7 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
 			 50,
 			 gcomprisBoard->height - 50,
 			 gcomprisBoard->number_of_sublevel);
-    gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK);
+    gc_bar_set(GC_BAR_LEVEL);
 
     algebra_guesscount_next_level();
 
@@ -327,6 +326,7 @@ static void update_line_calcul() {
     gnome_canvas_item_set(calcul_line_item[line*2+1],      "text", BLANK, NULL);
     gnome_canvas_item_set(calcul_line_item_back[line*2+1], "text", BLANK, NULL);
   }
+
 }
 /* ==================================== */
 static int generate_numbers() {
@@ -334,7 +334,7 @@ static int generate_numbers() {
   gboolean minus, divide;
 
   for (i=0; i<gcomprisBoard->level+1; i++) {
-    j = RAND(0,NUM_VALUES-1);
+    j = g_random_int_range(0,NUM_VALUES-1);
     answer_num_index[i] = j;
   }
 
@@ -350,7 +350,7 @@ static int generate_numbers() {
     }
     r = 2 + minus + divide;
 
-    switch (RAND(1,r)) {
+    switch (g_random_int_range(1,r)) {
     case 1 :
       answer_oper[i] = '+';
       result += num_values[answer_num_index[i+1]];
@@ -377,7 +377,7 @@ static int generate_numbers() {
       }
       break;
     case 4 :
-      if ( RAND(0,1) == 0) {
+      if ( g_random_int_range(0,1) == 0) {
 	answer_oper[i] = '-';
 	result -= num_values[answer_num_index[i+1]];
 	g_assert(result >= 0);
@@ -539,7 +539,7 @@ static void game_won() {
     gcomprisBoard->level++;
 
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) {
-      gc_bonus_end_display(BOARD_FINISHED_TUXPLANE);
+      gc_bonus_end_display(GC_BOARD_FINISHED_TUXPLANE);
       return;
     }
     gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),background_images[gcomprisBoard->level-1]);
@@ -547,18 +547,13 @@ static void game_won() {
   algebra_guesscount_next_level();
 }
 
-/* ==================================== */
-static void process_ok(){
-  gamewon = (result_to_find == token_result());
-  process_time_id = gtk_timeout_add (50, (GtkFunction) process_time, NULL);
-}
 /* ==================================== */
 static void process_time(){
   if (process_time_id) {
     gtk_timeout_remove (process_time_id);
     process_time_id = 0;
   }
-  gc_bonus_display(gamewon, BONUS_RANDOM);
+  gc_bonus_display(gamewon, GC_BONUS_RANDOM);
 }
 /* ==================================== */
 static int oper_char_to_pixmap_index(char oper) {
@@ -586,6 +581,7 @@ static gint item_event_oper(GnomeCanvasItem *item, GdkEvent *event, gpointer dat
 
   switch (event->type) {
   case GDK_BUTTON_PRESS:
+    gc_sound_play_ogg ("sounds/flip.wav", NULL);
     ptr_token_selected[token_count] = t;
     tmp_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_pixbuf_get_type (),
@@ -613,6 +609,7 @@ static gint item_event_oper_moved(GnomeCanvasItem *item, GdkEvent *event, gpoint
   // we only allow the undo of an operation if it is the last element displayed
   switch (event->type) {
   case GDK_BUTTON_PRESS:
+    gc_sound_play_ogg ("sounds/flip.wav", NULL);
     if (count == token_count) {
       gtk_object_destroy (GTK_OBJECT(item));
       token_count--;
@@ -633,6 +630,7 @@ static gint item_event_num(GnomeCanvasItem *item, GdkEvent *event, gpointer data
 
   switch (event->type){
   case GDK_BUTTON_PRESS:
+    gc_sound_play_ogg ("sounds/bleep.wav", NULL);
     if (t->isMoved) {
       if (item != ptr_token_selected[token_count-1]->item)
 	return FALSE;
@@ -666,6 +664,12 @@ static gint item_event_num(GnomeCanvasItem *item, GdkEvent *event, gpointer data
 	  gnome_canvas_item_set(calcul_line_item[token_count-2], "text", str, NULL);
 	  gnome_canvas_item_set(calcul_line_item_back[token_count-2], "text", str, NULL);
 	}
+
+	gamewon = (result_to_find == token_result());
+	if(gamewon)
+	  process_time_id = gtk_timeout_add (2000, (GtkFunction) process_time, NULL);
+
+
       }
     }
     break;
