@@ -16,8 +16,6 @@
 #include <awele_utils.h>
 #include <awele.h>
 #include <string.h>
-#include <unistd.h>
-
 
 static GcomprisBoard *gcomprisBoard = NULL;
 static gboolean board_paused = TRUE;
@@ -587,7 +585,7 @@ game_won ()
 			// finished
 			// : bail
 			// out
-	    gc_bonus_end_display (BOARD_FINISHED_RANDOM);
+	    gc_bonus_end_display (GC_BOARD_FINISHED_RANDOM);
 	    return;
 	  }
 
@@ -624,17 +622,17 @@ initBoardGraphics (GRAPHICS_ELT * graphsElt)
 		     j < staticAwale->board[i] && idxTabBeans < NBTOTALBEAN;
 		     j++, idxTabBeans++)
 		{
-			k = 0 + rand () % 4;
+			k = 0 + g_random_int() % 4;
 			graphsElt->ptBeansHoleLink[idxTabBeans].beanPixbuf =
 				gnome_canvas_item_new (boardRootItem,
 						       gnome_canvas_pixbuf_get_type
 						       (), "x",
 						       (double) caseCoord[i] +
-						       rand () % 50, "y",
+						       g_random_int() % 50, "y",
 						       (double) (((i <
 								   6) ? 260 :
 								  130) +
-								 rand () %
+								 g_random_int() %
 								 60),
 						       "pixbuf",
 						       graphsElt->
@@ -684,7 +682,7 @@ static gboolean  to_computer(gpointer data)
       /* Human player win by catching all the beans left. */
       gamewon = TRUE;
       sublevel_finished = TRUE;
-      gc_bonus_display(TRUE, BONUS_FLOWER);
+      gc_bonus_display(TRUE, GC_BONUS_FLOWER);
     }
   } else {
     /* computer can't play. Why? human is hungry and i cannot give it
@@ -693,7 +691,7 @@ static gboolean  to_computer(gpointer data)
     /* if not, all staying are captured by computer and computer win */
     gamewon = TRUE;
     sublevel_finished = (staticAwale->CapturedBeans[HUMAN] ==  24);
-    gc_bonus_display(sublevel_finished, BONUS_FLOWER);
+    gc_bonus_display(sublevel_finished, GC_BONUS_FLOWER);
   }
 
   timeout = 0;
@@ -858,15 +856,15 @@ updateNbBeans (int alpha)
 	   j++, idxTabBeans++)
 	{
 
-	  k = 0 + rand () % 4;
+	  k = 0 + g_random_int() % 4;
 
 	  gnome_canvas_item_set (ptBeansHoleLink[idxTabBeans].
 				 beanPixbuf, "x",
 				 (double) caseCoord[i] +
-				 rand () % 50, "y",
+				 g_random_int() % 50, "y",
 				 (double) (((i <
 					     6) ? 260 : 130) +
-					   rand () % 60), NULL);
+					   g_random_int() % 60), NULL);
 
 	  ptBeansHoleLink[idxTabBeans].hole = i;
 	}
@@ -903,7 +901,7 @@ updateCapturedBeans ()
  		  {
  		    gamewon = TRUE;
 		    sublevel_finished = (i==0);
- 		    gc_bonus_display(sublevel_finished, BONUS_FLOWER);
+ 		    gc_bonus_display(sublevel_finished, GC_BONUS_FLOWER);
  		  }
 	}
 }
