@@ -129,7 +129,7 @@ static gint		 arrow_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 static guint		 smooth_move(move_object *);
 static int		 is_allowed_move (double, double, int);
 static void		 shuffle_list(int list[], int);
-static void		 select_item(GnomeCanvasItem *, int);
+static void		 select_item(GnomeCanvasItem *);
 static int		 get_item_index (double, double);
 
 static void draw_arrow(void);
@@ -341,15 +341,15 @@ static GnomeCanvasItem *crane_create_item()
 // Display an happy face for end of level
 static void bonus() {
 
-  gc_bonus_display(gamewon, BONUS_SMILEY);
-  gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+  gc_bonus_display(gamewon, GC_BONUS_SMILEY);
+  gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   timer_id = 0;
 }
 
 // Display a 'end of game' animation
 static void finished() {
 
-  gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+  gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
   timer_id = 0;
 }
 
@@ -382,7 +382,10 @@ static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
 
   // Select item if left click on it
   if (event->type == GDK_BUTTON_PRESS && event->button.button == 1)
-	select_item(item, TRUE);
+    {
+      gc_sound_play_ogg ("sounds/bleep.wav", NULL);
+      select_item(item);
+    }
 
   return FALSE;
 }
@@ -414,6 +417,7 @@ static gint arrow_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
 
   // Left click on an arrow move the selected item
   if (event->type == GDK_BUTTON_PRESS && event->button.button == 1) {
+        gc_sound_play_ogg ("sounds/scroll.wav", NULL);
 	x = event->button.x;
 	y = event->button.y;
 
@@ -635,7 +639,7 @@ static void place_item(int x, int y, int active) {
 
   // 'Focus' given to the last one
   if (active)
-	select_item(item_image, FALSE);
+	select_item(item_image);
 
 }
 
@@ -696,8 +700,8 @@ void shuffle_list(int list[], int size) {
 
   for (i = 0 ; i < size ; i++) {
 
-	rand1 = RAND(0, size-1);
-	rand2 = RAND(0, size-1);
+	rand1 = g_random_int_range(0, size-1);
+	rand2 = g_random_int_range(0, size-1);
 
 	buffer = list[rand2];
 	list[rand2] = list[rand1];
@@ -705,7 +709,7 @@ void shuffle_list(int list[], int size) {
   }
 }
 
-static void select_item(GnomeCanvasItem *item, int sound) {
+static void select_item(GnomeCanvasItem *item) {
 
   double dx1, dy1, dx2, dy2;
 
@@ -732,8 +736,6 @@ static void select_item(GnomeCanvasItem *item, int sound) {
 			 "points", crane_rope,
 			 NULL);
 
-  if (sound) gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
-
   selected_item = item;
 }
 
