@@ -296,10 +296,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
       return;
     }
-    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+    gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   }
   fifteen_next_level();
 }
@@ -326,7 +326,7 @@ test_win (GnomeCanvasItem **board)
 
   gamewon = TRUE;
   fifteen_destroy_all_items();
-  gc_bonus_display(gamewon, BONUS_SMILEY);
+  gc_bonus_display(gamewon, GC_BONUS_SMILEY);
 
 }
 
@@ -431,7 +431,8 @@ scramble (GnomeCanvasItem **board, guint number_of_scrambles)
   int dir;
   int x, y;
 
-  srand (time (NULL));
+  /* g_random are initialised in gcompris launch */
+  /* srand (time (NULL)); */
 
   /* First, find the blank spot */
 
@@ -443,7 +444,7 @@ scramble (GnomeCanvasItem **board, guint number_of_scrambles)
 
   for (i = 0; i < number_of_scrambles; i++) {
   retry_scramble:
-    dir = rand () % 4;
+    dir = g_random_int () % 4;
 
     x = y = 0;
 
