@@ -1,6 +1,6 @@
 /* gcompris - gletters.c
  *
- * Time-stamp: <2006/08/21 23:33:17 bruno>
+ * Time-stamp: <2007-04-15 21:15:19 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -313,7 +313,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
       gcomprisBoard=agcomprisBoard;
       load_default_charset();
-      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery_background.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "opt/scenery_background.png");
       gcomprisBoard->maxlevel=maxLevel;
       gcomprisBoard->level = 1;
       level_set_score();
@@ -523,7 +523,6 @@ static void gletters_destroy_item(GnomeCanvasItem *item)
   item2del_list = g_list_remove (item2del_list, item);
 
   /* Remove old letter; this destroy the canvas item  */
-  g_warning("destroying %d", *key);
   g_hash_table_remove (letters_table, key);
 
 }
@@ -611,7 +610,7 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
     {
       attempt++;
       str_p = letters_array[gcomprisBoard->level-1];
-      i = (int)((float)k*rand()/(RAND_MAX+1.0));
+      i = g_random_int_range(0,k);
 
       for(j = 0; j < i; j++)
 	{
@@ -651,7 +650,7 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
 			   "y", (double) -12,
 			   NULL);
 
-  x = 80 + (int)((float)(gcomprisBoard->width-160)*rand()/(RAND_MAX+1.0));
+  x = g_random_int_range( 80, gcomprisBoard->width-160);
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(item),
 			 gnome_canvas_text_get_type (),
 			 "text", letter,
@@ -682,8 +681,6 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
 
   g_free(letter);
 
-  g_warning("done\n");
-
   return (item);
 }
 
@@ -698,6 +695,7 @@ static void gletters_add_new_item()
  */
 static gint gletters_drop_items (GtkWidget *widget, gpointer data)
 {
+  gc_sound_play_ogg ("sounds/level.wav", NULL);
   gletters_add_new_item();
 
   drop_items_id = gtk_timeout_add (fallSpeed,
@@ -707,10 +705,8 @@ static gint gletters_drop_items (GtkWidget *widget, gpointer data)
 
 static void player_win(GnomeCanvasItem *item)
 {
-  g_message("in player_win\n");
-
   gletters_destroy_item(item);
-  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+  gc_sound_play_ogg ("sounds/flip.wav", NULL);
 
   gcomprisBoard->sublevel++;
 
@@ -720,13 +716,13 @@ static void player_win(GnomeCanvasItem *item)
       gcomprisBoard->level++;
       if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
         gc_score_end();
-	gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+	gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
 	return;
       }
 
       gamewon = TRUE;
       gletters_destroy_all_items();
-      gc_bonus_display(gamewon, BONUS_SMILEY);
+      gc_bonus_display(gamewon, GC_BONUS_SMILEY);
     }
   else
     {
@@ -746,15 +742,11 @@ static void player_win(GnomeCanvasItem *item)
 	  }
 	}
     }
-  g_warning("leaving player_win\n");
 }
 
 static void player_loose()
 {
-  g_warning("entering player_loose\n");
-
-  gc_sound_play_ogg ("sounds/crash.ogg", NULL);
-  g_warning("leaving player_loose\n");
+  gc_sound_play_ogg ("sounds/crash.wav", NULL);
 }
 
 static gunichar *
@@ -862,7 +854,7 @@ gletter_config_start(GcomprisBoard *agcomprisBoard,
   if (gcomprisBoard)
     pause_board(TRUE);
 
-  label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+  label = g_strdup_printf(_("<b>%s</b> configuration\n for profile <b>%s</b>"),
 			  agcomprisBoard->name, aProfile ? aProfile->name : "");
 
   gc_board_config_window_display(label, (GcomprisConfCallback )conf_ok);
@@ -891,7 +883,7 @@ gletter_config_start(GcomprisBoard *agcomprisBoard,
   else
     with_sound = FALSE;
 
-  gc_board_config_boolean_box("Enable sounds", "with_sound", with_sound);
+  gc_board_config_boolean_box(_("Enable sounds"), "with_sound", with_sound);
 
   gc_board_conf_separator();
 
