@@ -318,11 +318,11 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
     gnome_canvas_item_new (boardRootItem,
 			   gnome_canvas_pixbuf_get_type (),
 			   "pixbuf", pixmap,
-			   "x",	(double)BOARDWIDTH/2,
-			   "y",	(double)BOARDHEIGHT - 35,
+			   "x",	(double)10,
+			   "y",	(double)BOARDHEIGHT - 60,
 			   "width", (double) BOARDWIDTH - 20,
 			   "width_set", TRUE,
-			   "anchor", GTK_ANCHOR_CENTER,
+			   "anchor", GTK_ANCHOR_NW,
 			   NULL);
     gdk_pixbuf_unref(pixmap);
   }
@@ -371,7 +371,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
   /* Initialize a random goal and store the color index in position[number_of_item_x] */
   for(i=0; i<(number_of_item_y); i++)
     {
-      guint color = (guint)RAND(0, NUMBER_OF_COLOR-1);
+      guint color = (guint)g_random_int_range(0, NUMBER_OF_COLOR-1);
       position[number_of_item_x+1][i]->color = color;
       used_colors[color] = TRUE;
 
@@ -386,10 +386,10 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 	{
 	  done = FALSE;
 
-	  i = (guint)RAND(0, number_of_item_x-2);
+	  i = (guint)g_random_int_range(0, number_of_item_x);
 
 	  /* Restrict the goal to lowest items */
-	  j = (guint)RAND(0, 2);
+	  j = (guint)g_random_int_range(0, 2);
 
 	  if(position[i][j]->color == -1)
 	    {
@@ -408,14 +408,12 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 	  if(position[i][j]->color == -1)
 	    {
 	      /* Take only a color that is not part of the goal */
-	      guint color = (guint)RAND(0, NUMBER_OF_COLOR-1);
-	      //printf(" i,j=%d,%d random color = %d used_colors[color]=%d\n", i,j,color, used_colors[color]);
+	      guint color = (guint)g_random_int_range(0, NUMBER_OF_COLOR-1);
 	      while(used_colors[color])
 		{
-		  //printf("  used_colors[%d]=%d\n", color, used_colors[color]);
-        color++;
-		if(color >= NUMBER_OF_COLOR)
-		  color = 0;
+		  color++;
+		  if(color >= NUMBER_OF_COLOR)
+		    color = 0;
 		}
 
 	      position[i][j]->color = color;
@@ -569,10 +567,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
       return;
     }
-    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+    gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   }
   hanoi_next_level();
 }
@@ -635,6 +633,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
       switch(event->button.button)
 	{
 	case 1:
+	  gc_sound_play_ogg ("sounds/bleep.wav", NULL);
 
 	  x = item_x;
 	  y = item_y;
@@ -690,6 +689,8 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  /* Bad drop / On the same column */
 	  if(col<0 || col > number_of_item_x || col == data->i)
 	    {
+	      gc_sound_play_ogg ("sounds/eraser2.wav", NULL);
+
 	      /* Return to the original position */
 	      gc_item_absolute_move (data->item     , data->x , data->y);
 	      gc_item_absolute_move (data->item_text, data->xt, data->yt);
@@ -710,6 +711,8 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  /* Bad drop / Too many pieces here */
 	  if(line >= number_of_item_y)
 	    {
+	      gc_sound_play_ogg ("sounds/eraser2.wav", NULL);
+
 	      /* Return to the original position */
 	      gc_item_absolute_move (data->item     , data->x , data->y);
 	      gc_item_absolute_move (data->item_text, data->xt, data->yt);
@@ -734,6 +737,8 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  gc_item_absolute_move (data->item     , piece_dst->x , piece_dst->y);
 	  gc_item_absolute_move (data->item_text, piece_dst->xt, piece_dst->yt);
 
+	  gc_sound_play_ogg ("sounds/scroll.wav", NULL);
+
 	  /* FIXME : Workaround for bugged canvas */
 	  gnome_canvas_update_now(gcomprisBoard->canvas);
 
@@ -767,7 +772,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	    {
 	      gamewon = TRUE;
 	      hanoi_destroy_all_items();
-	      gc_bonus_display(gamewon, BONUS_SMILEY);
+	      gc_bonus_display(gamewon, GC_BONUS_SMILEY);
 	    }
 	}
       break;
