@@ -314,7 +314,7 @@ static GnomeCanvasItem *leftright_create_item(GnomeCanvasGroup *parent) {
 
   // make sure that next hand is not the same as previous
   do {
-    i = RAND(0,gcomprisBoard->level*8-1);
+    i = g_random_int_range(0,gcomprisBoard->level*8-1);
   } while ( i == last_hand );
 
   last_hand = i;
@@ -356,7 +356,7 @@ static void game_won() {
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      gc_bonus_end_display(BOARD_FINISHED_TUXLOCO);
+      gc_bonus_end_display(GC_BOARD_FINISHED_TUXLOCO);
       return;
     }
   }
@@ -367,7 +367,7 @@ static void game_won() {
  *
  * =====================================================================*/
 static gboolean process_ok_timeout() {
-  gc_bonus_display(gamewon, BONUS_SMILEY);
+  gc_bonus_display(gamewon, GC_BONUS_SMILEY);
   return FALSE;
 }
 
@@ -396,6 +396,7 @@ static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
 
       if (y>CLICKABLE_Y1 && y<CLICKABLE_Y2) {
 	if (x>CLICKABLE_X1 && x<CLICKABLE_X2) { // the left button is clicked
+	  gc_sound_play_ogg ("sounds/bleep.wav", NULL);
 	  board_paused = TRUE;
 	  side = LEFT;
 	  highlight_selected(side);
@@ -403,6 +404,7 @@ static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
           process_ok();
 	}
 	if (x>CLICKABLE_X3 && x<CLICKABLE_X4) { // the left button is clicked
+	  gc_sound_play_ogg ("sounds/bleep.wav", NULL);
 	  board_paused = TRUE;
 	  side = RIGHT;
 	  highlight_selected(side);
