@@ -272,7 +272,7 @@ static void maze_next_level() {
 
   gamewon = FALSE;
   initMaze();
-  generateMaze((rand()%breedte),(rand()%hoogte));
+  generateMaze((g_random_int()%breedte),(g_random_int()%hoogte));
   removeSet();
   /* Try the next level */
   maze_create_item(gnome_canvas_root(gcomprisBoard->canvas));
@@ -283,8 +283,8 @@ static void maze_next_level() {
   }
 
   /* make a new group for the items */
-  begin=rand()%hoogte;
-  end=rand()%hoogte;
+  begin=g_random_int()%hoogte;
+  end=g_random_int()%hoogte;
 
   /* Draw the tux */
   pixmap = gc_pixmap_load("gcompris/misc/tux_top_east.png");
@@ -497,7 +497,7 @@ static GnomeCanvasItem *maze_create_item(GnomeCanvasGroup *parent) {
   warning_item = gnome_canvas_item_new (boardRootItem,
 					gnome_canvas_text_get_type (),
 					"text", message,
-					"font", gc_skin_font_board_big,
+					"font", gc_skin_font_board_small,
 					"x", (double) BOARDWIDTH/2,
 					"y", (double) BOARDHEIGHT-20,
 					"anchor", GTK_ANCHOR_CENTER,
@@ -512,13 +512,14 @@ static GnomeCanvasItem *maze_create_item(GnomeCanvasGroup *parent) {
  * =====================================================================*/
 static void game_won() {
   twoDdisplay();
-  gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   /* Try the next level */
   gcomprisBoard->level++;
-  if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-    gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+  if(gcomprisBoard->level > gcomprisBoard->maxlevel) { // the current board is finished : bail out
+    gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
     return;
   }
+  gc_sound_play_ogg ("sounds/bonus.wav", NULL);
+
   maze_next_level();
 }
 /* =====================================================================
@@ -723,7 +724,7 @@ static void generateMaze(int x, int y)
     {
       int nr = *po;
       int ran, in;
-      in=(rand()%nr)+1;
+      in=(g_random_int()%nr)+1;
       //printf("random: %d en %d mogelijkheden\n", in, *po);
       ran=*(po + in);
       if (nr>=1)
@@ -804,9 +805,14 @@ static void movePos(int x1, int y1, int x2,int y2, int richting)
   int ret,wall,i,bo=1;
   ret=1;
   wall=Maze[x1][y1];
-  if (wall&richting) ret=0;
+  if (wall&richting)
+    {
+      gc_sound_play_ogg ("sounds/brick.wav", NULL);
+      ret=0;
+    }
   if (ret)
     {
+      gc_sound_play_ogg ("sounds/prompt.wav", NULL);
       if (Maze[x2][y2]&SET)
 	{
 	  for (i=(ind); i>=0 && bo; i--)
@@ -836,7 +842,11 @@ static void movePos(int x1, int y1, int x2,int y2, int richting)
 	  position[ind][1]=y2;
 	  Maze[x2][y2]|=SET;
 	  if (position[ind][0]==(breedte-1) && position[ind][1]==(end))
-	    game_won();
+	    {
+	      gamewon = TRUE;
+	      twoDdisplay();
+	      gc_bonus_display(gamewon, GC_BONUS_LION);
+	    }
 	  else
 	    {
 	      move_image(mazegroup,x2,y2,tuxitem);
@@ -924,6 +934,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
     case GDK_3:
     case GDK_space:
       if(modeIsInvisible) {
+	gc_sound_play_ogg ("sounds/flip.wav", NULL);
 	if(mapActive) {
 	  gnome_canvas_item_hide(GNOME_CANVAS_ITEM(wallgroup));
 	  /* Hide the warning */
@@ -943,7 +954,11 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
       return TRUE;
     default: return FALSE;
     }
-  if (Maze[position[ind][0]][position[ind][1]]&richting) return TRUE;
+  if (Maze[position[ind][0]][position[ind][1]]&richting)
+    {
+      gc_sound_play_ogg ("sounds/brick.wav", NULL);
+      return TRUE;
+    }
   one_step(richting);
   viewing_direction=richting;
 
@@ -983,16 +998,19 @@ static gint key_press_2D_relative(guint keyval, gchar *commit_str, gchar *preedi
   switch (keyval)
     {
     case GDK_Left: viewing_direction=TURN_LEFT(viewing_direction);
+      gc_sound_play_ogg ("sounds/grow.wav", NULL);
       update_tux(viewing_direction);
       return TRUE;
       break;
     case GDK_Right: viewing_direction=TURN_RIGHT(viewing_direction);
+      gc_sound_play_ogg ("sounds/grow.wav", NULL);
       update_tux(viewing_direction);
       return TRUE;
       break;
     case GDK_Up: one_step(viewing_direction);
       break;
     case GDK_Down:
+      gc_sound_play_ogg ("sounds/grow.wav", NULL);
       viewing_direction=TURN_RIGHT(viewing_direction);
       viewing_direction=TURN_RIGHT(viewing_direction);
       update_tux(viewing_direction);
@@ -1018,15 +1036,17 @@ static gint key_press_3D(guint keyval, gchar *commit_str, gchar *preedit_str)
   switch (keyval)
     {
     case GDK_Left: viewing_direction=TURN_LEFT(viewing_direction);
+      gc_sound_play_ogg ("sounds/grow.wav", NULL);
       break;
     case GDK_Right: viewing_direction=TURN_RIGHT(viewing_direction);
+      gc_sound_play_ogg ("sounds/grow.wav", NULL);
       break;
     case GDK_Up: one_step(viewing_direction);
       break;
     case GDK_Down:
       viewing_direction=TURN_RIGHT(viewing_direction);
       viewing_direction=TURN_RIGHT(viewing_direction);
-      update_tux(viewing_direction);
+      gc_sound_play_ogg ("sounds/grow.wav", NULL);
       break;
     case GDK_2:
     case GDK_space:
@@ -1148,8 +1168,9 @@ static struct vector invert_y(struct vector v)
 
 static gboolean is_visible(struct vector viewpos, int viewdir,
 			   struct vector distance, gboolean left_side, gboolean *is_exit)
-{  struct vector where=vector_add(viewpos,invert_y(vector_turn(distance,angle(viewdir,NORTH))));
- gint direction=left_side ? TURN_LEFT(viewdir) : viewdir;
+{
+  struct vector where=vector_add(viewpos,invert_y(vector_turn(distance,angle(viewdir,NORTH))));
+  gint direction=left_side ? TURN_LEFT(viewdir) : viewdir;
 
  if (is_wall2(where,direction))
    return TRUE;
@@ -1158,8 +1179,9 @@ static gboolean is_visible(struct vector viewpos, int viewdir,
 	 && (where.y==end
 	     || (direction==NORTH && where.y==end+1)
 	     || (direction==SOUTH && where.y==end-1))))
-   {  *is_exit=TRUE;
-   return TRUE;
+   {
+     *is_exit=TRUE;
+     return TRUE;
    }
  return FALSE;
 }
@@ -1299,10 +1321,11 @@ static const char *color(int dir)
 
 static void gcDisplay(struct vector position, int viewdir,
 		    struct screenparam sp, int xmin, int xmax, int dy, gboolean left_wall)
-{  int dxl=dx_left(sp,xmin,dy,left_wall),
-     dxr=dx_right(sp,xmax,dy,left_wall),
-     i=0;
- gboolean is_exit=FALSE;
+{
+  int dxl=dx_left(sp,xmin,dy,left_wall),
+    dxr=dx_right(sp,xmax,dy,left_wall),
+    i=0;
+  gboolean is_exit=FALSE;
 
  if (dxl<=0) // seek from the middle left for a wall
    {  if (dxr<i) i=dxr;
@@ -1327,16 +1350,17 @@ static void gcDisplay(struct vector position, int viewdir,
      ++i;
    }
  if (i<=dxr) // wall found
-   {  struct Trapez t=Trapez_hide(wall_coords(sp,vector_ctor(i,dy),left_wall),xmin,xmax);
-   draw_Trapez(threedgroup,t,is_exit?"green":color(left_wall?TURN_RIGHT(viewdir):viewdir),"black");
-   // draw right of it
-   if (t.x_right+1<xmax)
-     gcDisplay(position,viewdir,sp,t.x_right+1,xmax,dy,left_wall);
-   // draw right of it
-   if (t.x_right+1<xmax)
-     gcDisplay(position,viewdir,sp,t.x_right+1,xmax,dy,left_wall);
-   // left of it ...
-   xmax=t.x_left-1;
+   {
+     struct Trapez t=Trapez_hide(wall_coords(sp,vector_ctor(i,dy),left_wall),xmin,xmax);
+     draw_Trapez(threedgroup,t,is_exit?"green":color(left_wall?TURN_RIGHT(viewdir):viewdir),"black");
+     // draw right of it
+     if (t.x_right+1<xmax)
+       gcDisplay(position,viewdir,sp,t.x_right+1,xmax,dy,left_wall);
+     // draw right of it
+     if (t.x_right+1<xmax)
+       gcDisplay(position,viewdir,sp,t.x_right+1,xmax,dy,left_wall);
+     // left of it ...
+     xmax=t.x_left-1;
    }
 
  if (xmin<=xmax) // draw in the middle (no wall there)
@@ -1345,8 +1369,9 @@ static void gcDisplay(struct vector position, int viewdir,
 
 static void Display3(struct vector position, int viewdir,
 		     struct screenparam sp)
-{  gcDisplay(position, viewdir, sp, sp.pos.x-sp.size.x, sp.pos.x+sp.size.x,
-	   0, TRUE);
+{
+  gcDisplay(position, viewdir, sp, sp.pos.x-sp.size.x, sp.pos.x+sp.size.x,
+	    0, TRUE);
 }
 
 static struct screenparam screenparam_ctor(int px,int py,int sx,int sy,int sdx,int sdy)
@@ -1365,7 +1390,10 @@ static void draw3D()
 #define MAINSY 240
 
   if (threedgroup!=NULL)
+  {
     gtk_object_destroy(GTK_OBJECT(threedgroup));
+    threedgroup = NULL;
+  }
   if (!threeDactive) return;
   threedgroup=GNOME_CANVAS_GROUP(gnome_canvas_item_new(gnome_canvas_root(gcomprisBoard->canvas),
 						       gnome_canvas_group_get_type(),
@@ -1379,6 +1407,7 @@ static void draw3D()
 static void twoDdisplay()
 {
   char *fileskin;
+  gc_sound_play_ogg ("sounds/flip.wav", NULL);
   fileskin = gc_skin_image_get("gcompris-bg.jpg");
   gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), fileskin);
   g_free(fileskin);
@@ -1391,7 +1420,8 @@ static void twoDdisplay()
 
 static void threeDdisplay()
 {
-  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/maze-bg.jpg");
+  gc_sound_play_ogg ("sounds/flip.wav", NULL);
+  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "opt/maze-bg.jpg");
   gnome_canvas_item_hide(GNOME_CANVAS_ITEM(boardRootItem));
   threeDactive=TRUE;
   draw3D();
@@ -1424,6 +1454,4 @@ static void update_tux(gint direction)
 			     NULL);
       gdk_pixbuf_unref(pixmap);
     }
-
-
 }
