@@ -1,6 +1,6 @@
 /* gcompris - menu2.c
  *
- * Time-stamp: <2006/08/21 23:34:21 bruno>
+ * Time-stamp: <2007-04-15 21:19:36 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -47,6 +47,8 @@ static MenuItems *menuitems;
 static GcomprisBoard *gcomprisBoard = NULL;
 static gboolean board_paused = TRUE;
 
+static gchar *menu_position = NULL;
+
 /* We don't wan't the callback on boards to be accepted until the menu is fully displayed */
 static gboolean menu_displayed = FALSE;
 
@@ -91,8 +93,8 @@ static double icon_size, icon_size_panel, icon_size_top, top_arrow_size;
 
 static gdouble get_ratio(GdkPixbuf *pixmap, gdouble size);
 
-#define P_X 0
-#define P_Y 10
+#define P_X 15
+#define P_Y 35
 #define P_W 80
 #define P_H 480
 
@@ -175,8 +177,6 @@ static void menu_pause (gboolean pause)
 static void menu_start (GcomprisBoard *agcomprisBoard)
 {
 
-  GcomprisProperties	*properties = gc_prop_get();
-
   current_x = 0.0;
   current_y = 0.0;
 
@@ -242,8 +242,8 @@ static void menu_start (GcomprisBoard *agcomprisBoard)
 
       create_panel(boardRootItem);
 
-      if (properties->menu_position){
-	display_section(properties->menu_position);
+      if (menu_position){
+	display_section(menu_position);
       }
       else
 	display_welcome();
@@ -270,7 +270,6 @@ static void create_panel(GnomeCanvasGroup *parent)
   GcomprisBoard *board;
   GdkPixbuf *pixmap = NULL;
   GnomeCanvasItem *item;
-  gdouble ratio;
 
   gdouble x, y;
   gint int_y;
@@ -302,20 +301,16 @@ static void create_panel(GnomeCanvasGroup *parent)
   for (list = panelBoards; list != NULL; list = list->next){
     board = (GcomprisBoard *) list->data;
 
-    pixmap = gc_pixmap_load(board->icon_name);
-
-    ratio = get_ratio( pixmap, icon_size_panel);
+    pixmap = gc_skin_pixmap_load(board->icon_name);
 
     item = gnome_canvas_item_new (parent,
 				  gnome_canvas_pixbuf_get_type (),
 				  "pixbuf", pixmap,
 				  "x", x,
 				  "y", y,
-				  "width", (gdouble)  gdk_pixbuf_get_width(pixmap)*ratio,
-				  "height", (gdouble) gdk_pixbuf_get_height(pixmap)*ratio,
-				  "width-set", TRUE,
-				  "height-set", TRUE,
-				  "anchor", GTK_ANCHOR_NW,
+				  "width", (gdouble)  gdk_pixbuf_get_width(pixmap),
+				  "height", (gdouble) gdk_pixbuf_get_height(pixmap),
+				  "anchor", GTK_ANCHOR_CENTER,
 				  NULL);
 
     gdk_pixbuf_unref(pixmap);
@@ -483,7 +478,7 @@ static void menu_create_item(GnomeCanvasGroup *parent, MenuItems *menuitems, Gco
    */
   tmp_board_dir = gcomprisBoard->board_dir;
   gcomprisBoard->board_dir = board->board_dir;
-  menu_pixmap = gc_pixmap_load(board->icon_name);
+  menu_pixmap = gc_skin_pixmap_load(board->icon_name);
   gcomprisBoard->board_dir = tmp_board_dir;
 
   ratio = get_ratio (menu_pixmap, icon_size);
@@ -524,7 +519,7 @@ static void menu_create_item(GnomeCanvasGroup *parent, MenuItems *menuitems, Gco
 
       /* We search a fixed path sound file */
       soundfile = gc_file_find_absolute(board->mandatory_sound_file);
-      g_warning("Checking mandatory_sound_file %s\n", soundfile);
+      g_warning("Checking mandatory_sound_file %s\n", board->mandatory_sound_file);
 
       if (!soundfile || !gc_prop_get()->fx)
 	{
@@ -652,22 +647,25 @@ item_event(GnomeCanvasItem *item, GdkEvent *event,  MenuItems *menuitems)
       if(!menu_displayed)
 	return TRUE;
 
-      gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 
-      if (strcmp(board->type,"menu")==0){
-	gchar *path = g_strdup_printf("%s/%s",board->section, board->name);
-	GcomprisProperties	*properties = gc_prop_get();
+      if (strcmp(board->type,"menu")==0)
+	{
+	  gchar *path = g_strdup_printf("%s/%s",board->section, board->name);
 
-	display_section(path);
+	  gc_sound_play_ogg ("sounds/bleep.wav", NULL);
+	  display_section(path);
 
-	if (properties->menu_position)
-	  g_free(properties->menu_position);
+	  if (menu_position)
+	    g_free(menu_position);
 
-	properties->menu_position = path;
+	  menu_position = path;
 
-      }
+	}
       else
-	gc_board_run_next (board);
+	{
+	  gc_sound_play_ogg ("sounds/level.wav", NULL);
+	  gc_board_run_next (board);
+	}
 
       break;
 
@@ -900,7 +898,7 @@ static void create_top(GnomeCanvasGroup *parent, gchar *path)
 
       if (current_top_x == 0.0){
 	current_top_x = top_x;
-	current_top_y = top_y + top_h/2.0;
+	current_top_y = top_y;
       } else {
 	pixmap = gc_skin_pixmap_load("button_forward.png");
 	ratio = get_ratio(pixmap, top_arrow_size);
@@ -909,12 +907,12 @@ static void create_top(GnomeCanvasGroup *parent, gchar *path)
 			       gnome_canvas_pixbuf_get_type (),
 			       "pixbuf", pixmap,
 			       "x", current_top_x,
-			       "y", current_top_y,
+			       "y", current_top_y + top_arrow_size / 2,
 			       "width", (gdouble)  gdk_pixbuf_get_width(pixmap)*ratio,
 			       "height", (gdouble) gdk_pixbuf_get_height(pixmap)*ratio,
 			       "width-set", TRUE,
 			       "height-set", TRUE,
-			       "anchor", GTK_ANCHOR_WEST,
+			       "anchor", GTK_ANCHOR_NW,
 			       NULL);
 
 	gdk_pixbuf_unref(pixmap);
@@ -925,7 +923,7 @@ static void create_top(GnomeCanvasGroup *parent, gchar *path)
 
       board = gc_menu_section_get(path1);
 
-      pixmap = gc_pixmap_load(board->icon_name);
+      pixmap = gc_skin_pixmap_load(board->icon_name);
 
       ratio = get_ratio( pixmap, icon_size_top);
 
@@ -938,7 +936,7 @@ static void create_top(GnomeCanvasGroup *parent, gchar *path)
 				    "height", (gdouble) gdk_pixbuf_get_height(pixmap)*ratio,
 				    "width-set", TRUE,
 				    "height-set", TRUE,
-				    "anchor", GTK_ANCHOR_WEST,
+				    "anchor", GTK_ANCHOR_NW,
 				    NULL);
 
       gdk_pixbuf_unref(pixmap);
