@@ -18,8 +18,14 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
 #include <Python.h>
+
+#if PY_VERSION_HEX < 0x02050000
+/* use int based index for python 2.4 and below */
+typedef int Py_ssize_t;
+#endif
+
+#define NO_IMPORT_PYGOBJECT 1
 #include <pygobject.h>
 #include "gcompris/gcompris.h"
 #include "py-mod-gcompris.h"
@@ -416,17 +422,17 @@ py_gc_log_set_comment(PyObject* self, PyObject* args)
 }
 
 
-/* void gc_log_end (GcomprisBoard *gcomprisBoard, gchar *status); */
+/* void gc_log_end (GcomprisBoard *gcomprisBoard, BonusStatusList status); */
 static PyObject*
 py_gc_log_end(PyObject* self, PyObject* args)
 {
   PyObject* pyGcomprisBoard;
   GcomprisBoard* cGcomprisBoard;
-  gchar* status;
+  int status;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args,
-		       "Os:gc_log_end",
+		       "Oi:gc_log_end",
 		       &pyGcomprisBoard,
 		       &status))
     return NULL;
@@ -434,7 +440,7 @@ py_gc_log_end(PyObject* self, PyObject* args)
 
   /* Call the corresponding C function */
   gc_log_end(cGcomprisBoard,
-		   status);
+	     status);
 
   /* Create and return the result */
   Py_INCREF(Py_None);
@@ -671,7 +677,7 @@ py_gcompris_child_watch_add(PyObject *unused, PyObject *args, PyObject *kwargs)
     static char *kwlist[] = { "pid", "function", "data", "priority", NULL };
     guint id;
     gint priority = G_PRIORITY_DEFAULT;
-    int pid;
+    GPid pid;
     PyObject *func, *user_data = NULL;
     struct _PyGChildData *child_data;
 
@@ -738,7 +744,7 @@ py_gcompris_spawn_async(PyObject *unused, PyObject *args, PyObject *kwargs)
     gint *standard_input, *standard_output, *standard_error;
     struct _PyGChildSetupData *callback_data = NULL;
     GError *error = NULL;
-    GPid child_pid = -1;
+    GPid child_pid = (GPid) -1;
     int len, i;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O|OsiOOOOO:gcompris.spawn_async",
@@ -1178,7 +1184,7 @@ py_gc_board_config_radio_buttons(PyObject* self, PyObject* args)
   }
 
   PyObject *pykey, *pyvalue;
-  int pos = 0;
+  Py_ssize_t pos = 0;
 
   buttons_label = g_hash_table_new_full (g_str_hash,
 				    g_str_equal,
@@ -1450,70 +1456,6 @@ py_gc_board_config_textview(PyObject* self, PyObject* args){
 }
 
 
-static PyObject*
-py_gc_prop_user_dirname_get (PyObject* self, PyObject* args)
-{
-  PyObject* pyUser;
-  pyGcomprisUserObject* pyGcomprisUser;
-  GcomprisUser* cGcomprisUser;
-
-  /* Parse arguments */
-  if(!PyArg_ParseTuple(args, "O:gcompris.get_user_dirname", &pyUser))
-    return NULL;
-
-  pyGcomprisUser = (pyGcomprisUserObject *) pyUser;
-
-  cGcomprisUser = pyGcomprisUser->cdata;
-
-  /* Call the corresponding C function */
-  return PyString_FromString(gc_prop_user_dirname_get(cGcomprisUser));
-
-}
-
-static PyObject*
-py_gc_prop_board_dirname_get (PyObject* self, PyObject* args)
-{
-  PyObject* pyBoard;
-  pyGcomprisBoardObject* pyGcomprisBoard;
-  GcomprisBoard* cGcomprisBoard;
-
-  /* Parse arguments */
-  if(!PyArg_ParseTuple(args, "O:gcompris.get_board_dirname", &pyBoard))
-    return NULL;
-
-  pyGcomprisBoard = (pyGcomprisBoardObject *) pyBoard;
-
-  cGcomprisBoard = pyGcomprisBoard->cdata;
-
-  /* Call the corresponding C function */
-  return PyString_FromString(gc_prop_board_dirname_get(cGcomprisBoard));
-
-}
-
-static PyObject*
-py_gc_prop_current_user_dirname_get (PyObject* self, PyObject* args)
-{
-  /* Parse arguments */
-  if(!PyArg_ParseTuple(args, ":gcompris.get_current_user_dirname"))
-    return NULL;
-
-  /* Call the corresponding C function */
-  return PyString_FromString(gc_prop_current_user_dirname_get());
-
-}
-
-static PyObject*
-py_gc_prop_current_board_dirname_get (PyObject* self, PyObject* args)
-{
-  /* Parse arguments */
-  if(!PyArg_ParseTuple(args, ":gcompris.get_current_board_dirname"))
-    return NULL;
-
-  /* Call the corresponding C function */
-  return PyString_FromString(gc_prop_current_board_dirname_get());
-
-}
-
 static PyObject*
 py_gcompris_wordlist_get_from_file (PyObject* self, PyObject* args)
 {
@@ -1602,10 +1544,6 @@ static PyMethodDef PythonGcomprisModule[] = {
   { "combo_locales_asset",  py_gc_board_config_combo_locales_asset, METH_VARARGS, "gc_board_config_combo_locales_asset" },
   { "get_locales_asset_list",  py_gc_locale_gets_asset_list, METH_VARARGS, "gc_locale_gets_asset_list" },
   { "textview",  py_gc_board_config_textview, METH_VARARGS, "gc_board_config_textview" },
-  { "get_user_dirname",  py_gc_prop_user_dirname_get, METH_VARARGS, "gc_prop_user_dirname_get" },
-  { "get_current_user_dirname",  py_gc_prop_current_user_dirname_get, METH_VARARGS, "gc_prop_current_user_dirname_get" },
-  { "get_board_dirname",  py_gc_prop_board_dirname_get, METH_VARARGS, "gc_prop_board_dirname_get" },
-  { "get_current_board_dirname",  py_gc_prop_current_board_dirname_get, METH_VARARGS, "gc_prop_current_board_dirname_get" },
   { "get_wordlist",  py_gcompris_wordlist_get_from_file, METH_VARARGS, "gcompris_wordlist_get_from_file" },
   { "im_reset",  py_gc_im_reset, METH_VARARGS, "gc_im_reset" },
   { NULL, NULL, 0, NULL}
@@ -1659,8 +1597,6 @@ void python_gcompris_module_init(void)
 
   /* Cursors constants */
   PyModule_AddIntConstant(gcomprisModule, "CURSOR_FIRST_CUSTOM",  GCOMPRIS_FIRST_CUSTOM_CURSOR);
-  PyModule_AddIntConstant(gcomprisModule, "CURSOR_BIG_RED_ARROW", GCOMPRIS_BIG_RED_ARROW_CURSOR);
-  PyModule_AddIntConstant(gcomprisModule, "CURSOR_BIRD",          GCOMPRIS_BIRD_CURSOR);
   PyModule_AddIntConstant(gcomprisModule, "CURSOR_LINE",          GCOMPRIS_LINE_CURSOR);
   PyModule_AddIntConstant(gcomprisModule, "CURSOR_FILLRECT",      GCOMPRIS_FILLRECT_CURSOR);
   PyModule_AddIntConstant(gcomprisModule, "CURSOR_RECT",          GCOMPRIS_RECT_CURSOR);
