@@ -85,7 +85,8 @@ class Gcompris_electric:
     #
     for binary in ("/usr/bin/gnucap",
                    "/usr/local/bin/gnucap",
-                   "gnucap.exe"):
+                   "gnucap.exe",
+		   os.path.join(gcompris.DATA_DIR, '..' , '..', '..', 'bin', 'gnucap')):
       if(os.path.exists(binary)):
         self.gnucap_binary = binary
         break
@@ -177,7 +178,7 @@ class Gcompris_electric:
     self.gamewon = False
 
     if self.gnucap_timer :
-      gtk.timeout_remove(self.gnucap_timer)
+      gobject.source_remove(self.gnucap_timer)
       self.gnucap_timer = 0
 
     # remove the appended items from our tools
@@ -333,10 +334,15 @@ class Gcompris_electric:
     # Ugly hack: connect a 0 ohm (1 fempto) resistor between net 0
     # and first net found
     gnucap += "R999999999 0 "
+    found = False
     for component in self.components:
       if component.is_connected():
-        gnucap += str(component.get_nodes()[0].get_wires()[0].get_wire_id())
-        break
+        for node in component.get_nodes():
+          if(node.get_wires()):
+            gnucap += str(node.get_wires()[0].get_wire_id())
+            found = True
+            break
+      if found: break
     gnucap += " 1f\n"
 
     gnucap_print = ""
