@@ -20,14 +20,15 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-import gnome
-import gnome.canvas
+import gobject
+import gnomecanvas
 import gcompris
 import gcompris.utils
 import gcompris.skin
 import gcompris.bonus
 import gcompris.score
 import gcompris.anim
+import gcompris.sound
 import gobject
 import gtk
 import gtk.gdk
@@ -43,7 +44,7 @@ class Number:
 class Square:
     def __init__(self, x, y):
         self.num = None
-        self.pic = game.rootitem.add( gnome.canvas.CanvasText,
+        self.pic = game.rootitem.add( gnomecanvas.CanvasText,
                                       text = "",
                                       font = gcompris.skin.get_font("gcompris/content"),
                                       x = x,
@@ -148,13 +149,16 @@ class FactorLevelset:
         self.nonfactors = []
 
     def getError(self, num):
-        fmt = _('Multiples of %d include %s,\nbut %d is not a multiple of %d.')
+        # Translators: You can swap %(x)y elements in the string.
+        fmt = _('Multiples of %(d1)d include %(s)s,\nbut %(d2)d is not a multiple of %(d3)d.')
         n = int(num.text)
         mults = []
         for i in range(2, 5):
             mults.append(n*i)
-        s = makeNumList(mults) % tuple(mults)
-        return fmt % (n, s, self.level_multiple[self.cur_sublevel-1], n)
+        return fmt % { 'd1': n,
+                       's': makeNumList(mults) % tuple(mults),
+                       'd2': self.level_multiple[self.cur_sublevel-1],
+                       'd3': n }
 
     def getTitle(self):
         return _('Factors of %d') % ( self.level_multiple[self.cur_sublevel-1] )
@@ -322,10 +326,10 @@ class Player(object):
 
     def die(self):
         if self.movestep_timer != 0:
-            gtk.timeout_remove(self.movestep_timer)
+            gobject.source_remove(self.movestep_timer)
             self.movestep_timer = 0
         if self.munch_timer != 0:
-            gtk.timeout_remove(self.munch_timer)
+            gobject.source_remove(self.munch_timer)
             self.munch_timer = 0
 
     def getEaten(self):
@@ -343,10 +347,10 @@ class Player(object):
     def move_step(self):
         if self.move_stepnum < game.num_moveticks-1:
             self.move_stepnum += 1
-            x_old = self.anim.gnome_canvas.get_property("x")
-            y_old = self.anim.gnome_canvas.get_property("y")
-            x = self.anim.gnome_canvas.get_property("x") + self.velocity[0]*game.sw/game.num_moveticks
-            y = self.anim.gnome_canvas.get_property("y") + self.velocity[1]*game.sh/game.num_moveticks
+            x_old = self.anim.gnomecanvas.get_property("x")
+            y_old = self.anim.gnomecanvas.get_property("y")
+            x = self.anim.gnomecanvas.get_property("x") + self.velocity[0]*game.sw/game.num_moveticks
+            y = self.anim.gnomecanvas.get_property("y") + self.velocity[1]*game.sh/game.num_moveticks
             ret = True
         else:
             self.move_stepnum = 0
@@ -356,16 +360,17 @@ class Player(object):
             self.movestep_timer = 0
             ret = False
 
-        self.anim.gnome_canvas.set(x=x, y=y)
+        self.anim.gnomecanvas.set(x=x, y=y)
         return ret
 
     def move(self, x_old, y_old, x, y):
+        gcompris.sound.play_ogg("sounds/smudge.wav")
         self.x_old = x_old
         self.y_old = y_old
         self.x = x
         self.y = y
         self.velocity = [x-x_old, y-y_old]
-        self.anim.gnome_canvas.set(x=(self.x_old * game.sw + game.left),
+        self.anim.gnomecanvas.set(x=(self.x_old * game.sw + game.left),
                                    y=(self.y_old * game.sh + game.top))
         self.moving = True
 
@@ -377,6 +382,7 @@ class Player(object):
             self.stop()
 
     def startMunching(self):
+        gcompris.sound.play_ogg("sounds/eat.wav")
         self.anim.setState(2)
         self.munch_timer = game.timeout_add(game.munch_time, self.stopMunching)
         return False
@@ -407,28 +413,28 @@ class Muncher(Player):
         self.lives = 1
         self.anim = gcompris.anim.CanvasItem(game.munchanimation, game.rootitem)
         self.spare = gcompris.anim.CanvasItem(game.munchanimation, game.rootitem)
-        self.anim.gnome_canvas.hide()
+        self.anim.gnomecanvas.hide()
         self.key_queue = []
-        self.spare.gnome_canvas.set(x=0, y=0)
+        self.spare.gnomecanvas.set(x=0, y=0)
 
     def spawn(self):
         if self.lives >= 1:
-            self.spare.gnome_canvas.show()
+            self.spare.gnomecanvas.show()
         elif self.lives == 0:
-            self.spare.gnome_canvas.hide()
+            self.spare.gnomecanvas.hide()
         else:
             game.loseGame()
         self.key_queue = []
         game.hide_message()
         self.exists = True
         self.move(0,0,0,0)
-        self.anim.gnome_canvas.show()
+        self.anim.gnomecanvas.show()
 
     def die(self):
         super(Muncher, self).die()
         self.lives -= 1
         self.exists = False
-        self.anim.gnome_canvas.hide()
+        self.anim.gnomecanvas.hide()
         self.key_queue = []
 
     def getEaten(self):
@@ -530,19 +536,19 @@ class Troggle(Player):
                 self.y = game.height - 1
             self.x = self.x_old = random.randint(0, game.width-1)
         self.move(self.x_old, self.y_old, self.x, self.y)
-        self.anim.gnome_canvas.show()
+        self.anim.gnomecanvas.show()
         game.hide_trogwarning()
 
     def die(self):
         super(Troggle, self).die()
         self.exists = 0
-        self.anim.gnome_canvas.hide()
+        self.anim.gnomecanvas.hide()
 
         time = game.trog_spawn_time()
         self.nextspawn_timer = game.timeout_add( time + game.trogwarn_time, self.spawn )
         self.warn_timer = game.timeout_add( time, game.show_trogwarning )
         if self.nextmove_timer != 0:
-            gtk.timeout_remove(self.nextmove_timer)
+            gobject.source_remove(self.nextmove_timer)
             self.nextmove_timer = 0
 
     def getEaten(self):
@@ -708,19 +714,19 @@ class Gcompris_gnumch:
 
         # create our rootitem. We put each canvas item here so at the end we only
         # need to destroy the rootitem
-        self.rootitem = self.board.canvas.root().add(gnome.canvas.CanvasGroup,
+        self.rootitem = self.board.canvas.root().add(gnomecanvas.CanvasGroup,
                                                      x=0.0,
                                                      y=0.0)
 
         # draw the board on top of the background
         for i in range(0,self.width+1):
-            self.rootitem.add(gnome.canvas.CanvasLine,
+            self.rootitem.add(gnomecanvas.CanvasLine,
                               points = (i*self.sw + self.left, self.top,
                                         i*self.sw + self.left, self.scrh),
                               fill_color_rgba = 0x000000FFL,
                               width_units = 3.0)
         for i in range(0,self.height+1):
-            self.rootitem.add(gnome.canvas.CanvasLine,
+            self.rootitem.add(gnomecanvas.CanvasLine,
                               points = (self.left, self.top + i*self.sh,
                                         self.scrw, self.top + i*self.sh),
                               fill_color_rgba = 0x000000FFL,
@@ -745,46 +751,46 @@ class Gcompris_gnumch:
             self.squares.append(tmp)
 
         # so that the troggles get clipped to the board area
-        self.rootitem.add(gnome.canvas.CanvasRect,
+        self.rootitem.add(gnomecanvas.CanvasRect,
                           x1=0, y1=0,
                           x2=self.scrw, y2=self.top,
                           fill_color_rgba = 0xFFFFFFFFL)
-        self.rootitem.add(gnome.canvas.CanvasRect,
+        self.rootitem.add(gnomecanvas.CanvasRect,
                           x1=0, y1=0,
                           x2=self.left, y2=self.scrh,
                           fill_color_rgba = 0xFFFFFFFFL)
 
         # the board title
-        self.title = self.rootitem.add(gnome.canvas.CanvasText,
+        self.title = self.rootitem.add(gnomecanvas.CanvasText,
                                        text = "",
-                                       font = gcompris.skin.get_font("gcompris/board/huge bold"),
+                                       font = gcompris.skin.get_font("gcompris/board/title bold"),
                                        x = self.scrw/2,
                                        y = self.top/2)
 
         # the message
-        self.message_back = self.rootitem.add(gnome.canvas.CanvasRect,
+        self.message_back = self.rootitem.add(gnomecanvas.CanvasRect,
                                         x1=0, y1=0, x2=1, y2=1,
                                         fill_color_rgba = 0x60F06060L)
-        self.message = self.rootitem.add(gnome.canvas.CanvasText,
+        self.message = self.rootitem.add(gnomecanvas.CanvasText,
                                         text = "",
                                         justification = gtk.JUSTIFY_CENTER,
-                                        font = gcompris.skin.get_font("gcompris/board/huge bold"),
+                                        font = gcompris.skin.get_font("gcompris/board/title bold"),
                                         x = self.scrw/2,
                                         y = self.scrh/2)
         self.message.hide()
 
         # the trogwarning
-        self.trogwarning = self.rootitem.add(gnome.canvas.CanvasText,
+        self.trogwarning = self.rootitem.add(gnomecanvas.CanvasText,
                                         text = _("T\nR\nO\nG\nG\nL\nE"),
                                         justification = gtk.JUSTIFY_CENTER,
-                                        font = gcompris.skin.get_font("gcompris/board/huge bold"),
+                                        font = gcompris.skin.get_font("gcompris/board/title bold"),
                                         x = self.left/2,
                                         y = self.scrh/2)
         self.trogwarning.hide()
         self.trogwarning_num = 0
 
         # the spare life
-        self.muncher.spare.gnome_canvas.raise_to_top()
+        self.muncher.spare.gnomecanvas.raise_to_top()
 
         self.startGame()
 
@@ -846,14 +852,14 @@ class Gcompris_gnumch:
     def stopGame(self):
         self.stopped = 1
         if self.muncher.munch_timer != 0:
-            gtk.timeout_remove(self.muncher.munch_timer)
+            gobject.source_remove(self.muncher.munch_timer)
         if self.muncher.movestep_timer != 0:
-            gtk.timeout_remove(self.muncher.movestep_timer)
+            gobject.source_remove(self.muncher.movestep_timer)
 
         for t in self.troggles:
             for timer in [t.munch_timer, t.movestep_timer, t.nextmove_timer, t.nextspawn_timer, t.warn_timer]:
                 if timer != 0:
-                    gtk.timeout_remove(timer)
+                    gobject.source_remove(timer)
 
     def startGame(self):
         self.stopped = 0
@@ -875,7 +881,7 @@ class Gcompris_gnumch:
                 self.troggles[i].die()
             else: # don't move them into the spawning queue
                 self.troggles[i].exists = 0
-                self.troggles[i].anim.gnome_canvas.hide()
+                self.troggles[i].anim.gnomecanvas.hide()
         self.muncher.spawn()
 
     def winGame(self):
@@ -906,7 +912,7 @@ class Gcompris_gnumch:
             self.set_level( self.board.level % self.board.maxlevel + 1)
         else:
             self.startGame();
-            
+
 
     def repeat(self):
         self.stopGame()
@@ -914,7 +920,7 @@ class Gcompris_gnumch:
 
     def timeout_add(self, t, fn):
         if not self.paused and not self.stopped:
-            return gtk.timeout_add(t, fn)
+            return gobject.timeout_add(t, fn)
         else:
             return 0
 
