@@ -191,18 +191,22 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 9;
       gc_bar_set(GC_BAR_CONFIG|GC_BAR_LEVEL);
-
-      font_size = PANGO_PIXELS(pango_font_description_get_size (pango_font_description_from_string (gc_skin_font_board_medium)));
+      PangoFontDescription *font_medium = pango_font_description_from_string(gc_skin_font_board_medium);
+      font_size = PANGO_PIXELS(pango_font_description_get_size (font_medium));
       interline = (int) (1.5*font_size);
 
       PangoContext *pango_context = gtk_widget_get_pango_context  (GTK_WIDGET(agcomprisBoard->canvas));
 
       PangoFontMetrics* pango_metrics =  pango_context_get_metrics (pango_context,
-								    pango_font_description_from_string (gc_skin_font_board_medium),
+								    font_medium,
 								    pango_language_from_string   (gc_locale_get()));
+      pango_font_description_free(font_medium);
 
       int ascent = PANGO_PIXELS(pango_font_metrics_get_ascent (pango_metrics));
       int descent = PANGO_PIXELS(pango_font_metrics_get_descent (pango_metrics));
+
+      pango_font_metrics_unref(pango_metrics);
+
       interline = ascent + descent;
 
       g_warning ("Font to display words have size %d  ascent : %d, descent : %d.\n Set inerline to %d", font_size, ascent, descent, interline);
@@ -357,8 +361,7 @@ static GnomeCanvasItem *display_what_to_do(GnomeCanvasGroup *parent)
 {
 
   gint base_Y = 110;
-  gint base_X = 580;
-  gint i;
+  gint base_X = 570;
 
   /* Load the text to find */
 
@@ -368,20 +371,19 @@ static GnomeCanvasItem *display_what_to_do(GnomeCanvasGroup *parent)
 
   /* Decide now if this time we will display the text to find */
   /* Use this formula to have a better random number see 'man 3 rand' */
-  i=((int)(2.0*rand()/(RAND_MAX+1.0)));
-  if(i==0)
-      textToFindIndex = rand() % numberOfLine;
+  if(g_random_boolean())
+      textToFindIndex = g_random_int_range(0, numberOfLine);
   else
     textToFindIndex = NOT_THERE;
 
   gnome_canvas_item_new (parent,
 			 gnome_canvas_text_get_type (),
 			 "text", _("Please, check if the word"),
-			 "font", gc_skin_font_board_big,
+			 "font", gc_skin_font_board_medium,
 			 "x", (double) base_X,
 			 "y", (double) base_Y,
 			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color", "white",
+			 "fill_color", "black",
 			 NULL);
 
   gnome_canvas_item_new (parent,
@@ -397,11 +399,11 @@ static GnomeCanvasItem *display_what_to_do(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (parent,
 			 gnome_canvas_text_get_type (),
 			 "text", _("is being displayed"),
-			 "font", gc_skin_font_board_big,
+			 "font", gc_skin_font_board_medium,
 			 "x", (double) base_X,
 			 "y", (double) base_Y + 60,
 			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color", "white",
+			 "fill_color", "black",
 			 NULL);
 
 
@@ -659,11 +661,11 @@ static void player_win()
 {
   gamewon = TRUE;
   wait_for_ready = TRUE;
-  gc_bonus_display(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, GC_BONUS_FLOWER);
   /* Try the next level */
   gcomprisBoard->level++;
   if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-    gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+    gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
     return;
   }
 
@@ -690,7 +692,7 @@ static void player_loose()
   g_free(expected);
   g_free(got);
 
-  gc_bonus_display(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, GC_BONUS_FLOWER);
 
   next_level_timer = g_timeout_add(3000, (GtkFunction)reading_next_level, NULL);
 }
@@ -828,7 +830,7 @@ reading_config_start(GcomprisBoard *agcomprisBoard,
   if (gcomprisBoard)
     pause_board(TRUE);
 
-  gchar *label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+  gchar *label = g_strdup_printf(_("<b>%s</b> configuration\n for profile <b>%s</b>"),
 				 agcomprisBoard->name,
 				 aProfile? aProfile->name: "");
 
