@@ -81,13 +81,13 @@ static GnomeCanvasItem *clock_image_item;
 // List of images to use in the game
 static gchar *imageList[] =
 {
-  "reversecount/baleine.png",
-  "reversecount/phoque.png",
-  "reversecount/ourspolaire.png",
-  "reversecount/morse.png",
-  "reversecount/elephant_mer.png",
-  "reversecount/epaulard.png",
-  "reversecount/narval.png",
+  "opt/baleine.png",
+  "opt/phoque.png",
+  "opt/ourspolaire.png",
+  "opt/morse.png",
+  "opt/elephant_mer.png",
+  "opt/epaulard.png",
+  "opt/narval.png",
 };
 #define NUMBER_OF_IMAGES 10
 
@@ -173,7 +173,7 @@ static void pause_board (gboolean pause)
     }
 
   if(leavenow == TRUE && pause == FALSE)
-    gc_bonus_end_display(BOARD_FINISHED_TOOMANYERRORS);
+    gc_bonus_end_display(GC_BOARD_FINISHED_TOOMANYERRORS);
 
   board_paused = pause;
 }
@@ -282,14 +282,14 @@ gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 
 static void process_error()
 {
-  gc_sound_play_ogg ("sounds/crash.ogg", NULL);
+  gc_sound_play_ogg ("sounds/crash.wav", NULL);
   errors--;
   if(errors==0)
     {
       gamewon = FALSE;
       leavenow = TRUE;
       reversecount_destroy_all_items();
-      gc_bonus_display(gamewon, BONUS_SMILEY);
+      gc_bonus_display(gamewon, GC_BONUS_SMILEY);
     }
   else
     {
@@ -570,13 +570,13 @@ static void display_random_fish()
 {
 
   fish_index = tux_index +
-    rand()%(max_dice_number*number_of_dices) + 1;
+    g_random_int()%(max_dice_number*number_of_dices) + 1;
 
   // Wrapping
   if(fish_index >= number_of_item)
     fish_index = fish_index - (number_of_item);
 
-  fishItem = display_item_at(fishList[rand()%NUMBER_OF_FISHES],
+  fishItem = display_item_at(fishList[g_random_int()%NUMBER_OF_FISHES],
 			     fish_index, -1);
 }
 
@@ -670,10 +670,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
       return;
     }
-    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+    gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   }
   reversecount_next_level();
 }
@@ -822,13 +822,13 @@ static gint animate_tux()
 	  if(fishItem!=NULL)
 	    gtk_object_destroy(GTK_OBJECT(fishItem));
 
-	  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+	  gc_sound_play_ogg ("sounds/gobble.wav", NULL);
 
 	  if(--number_of_fish == 0)
 	    {
 	      gamewon = TRUE;
 	      reversecount_destroy_all_items();
-	      gc_bonus_display(gamewon, BONUS_SMILEY);
+	      gc_bonus_display(gamewon, GC_BONUS_SMILEY);
 	    }
 	  else
 	    {
