@@ -191,7 +191,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=1; /* Go to next level after this number of 'play' */
 
-      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/target_background.jpg");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "opt/target_background.jpg");
 
       target_next_level();
 
@@ -362,12 +362,12 @@ static void display_windspeed()
 							   NULL));
 
   /* Speed orientation */
-  second = rand()%60;
+  second = g_random_int()%60;
   ang = second * M_PI / 30;
 
   /* Speed force */
   wind_speed = targetDefinition[gcomprisBoard->level-1].target_min_wind_speed \
-    + rand()%(targetDefinition[gcomprisBoard->level-1].target_max_wind_speed \
+    + g_random_int()%(targetDefinition[gcomprisBoard->level-1].target_max_wind_speed \
 	      - targetDefinition[gcomprisBoard->level-1].target_min_wind_speed);
 
   canvasPoints->coords[0]=SPEED_CENTER_X;
@@ -494,10 +494,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
       return;
     }
-    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+    gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   }
   target_next_level();
 }
@@ -512,12 +512,12 @@ static void process_ok()
       {
 	gamewon = TRUE;
 	target_destroy_all_items();
-	gc_bonus_display(gamewon, BONUS_SMILEY);
+	gc_bonus_display(gamewon, GC_BONUS_SMILEY);
       }
     else
       {
 	gamewon = FALSE;
-	gc_bonus_display(gamewon, BONUS_SMILEY);
+	gc_bonus_display(gamewon, GC_BONUS_SMILEY);
       }
   }
 
@@ -606,6 +606,8 @@ static void animate_items()
 
   if(animate_item_distance-- == 0)
     {
+      gc_sound_play_ogg ("sounds/brick.wav", NULL);
+
       gtk_timeout_remove (animate_id);
       animate_id = 0;
       animate_item = NULL;
@@ -630,6 +632,8 @@ static void launch_dart(double item_x, double item_y)
   animate_item_size	= MAX_DART_SIZE;
   animate_item_distance	= targetDefinition[gcomprisBoard->level-1].target_distance/10;
 
+  gc_sound_play_ogg ("sounds/line_end.wav", NULL);
+
   animate_item = gnome_canvas_item_new (boardRootItem,
 					gnome_canvas_ellipse_get_type(),
 					"x1", (double)item_x-MAX_DART_SIZE,
