@@ -28,7 +28,7 @@ static struct BoardPluginData *bp_data;
 
 static gboolean	 get_board_playing(void);
 
-#ifdef WIN32
+#ifdef STATIC_MODULE
 int gc_activation_check(char *code);
 extern BoardPlugin * get_advanced_colors_bplugin_info();
 extern BoardPlugin * get_algebra_bplugin_info();
@@ -64,6 +64,7 @@ extern BoardPlugin * get_railroad_bplugin_info();
 extern BoardPlugin * get_read_colors_bplugin_info();
 extern BoardPlugin * get_reading_bplugin_info();
 extern BoardPlugin * get_reversecount_bplugin_info();
+extern BoardPlugin * get_scale_bplugin_info();
 extern BoardPlugin * get_shapegame_bplugin_info();
 extern BoardPlugin * get_smallnumbers_bplugin_info();
 extern BoardPlugin * get_submarine_bplugin_info();
@@ -72,6 +73,7 @@ extern BoardPlugin * get_target_bplugin_info();
 extern BoardPlugin * get_traffic_bplugin_info();
 extern BoardPlugin * get_wordsgame_bplugin_info();
 extern BoardPlugin * get_python_bplugin_info();
+extern BoardPlugin * get_wordprocessor_bplugin_info();
 
 #define MAX_NUMBER_OF_BOARDS 200
 static BoardPlugin *static_boards_demo[MAX_NUMBER_OF_BOARDS];
@@ -79,7 +81,7 @@ static BoardPlugin *static_boards[MAX_NUMBER_OF_BOARDS];
 
 #endif
 
-#ifdef WIN32
+#ifdef STATIC_MODULE
 int gc_board_number_in_demo;
 void gc_board_init(void)
 {
@@ -105,20 +107,22 @@ void gc_board_init(void)
   static_boards_demo[i++] = get_menu_bplugin_info();
   static_boards_demo[i++] = get_money_bplugin_info();
   static_boards_demo[i++] = get_reading_bplugin_info();
+  static_boards_demo[i++] = get_scale_bplugin_info();
   static_boards_demo[i++] = get_submarine_bplugin_info();
   static_boards_demo[i++] = get_superbrain_bplugin_info();
   static_boards_demo[i++] = get_target_bplugin_info();
+  static_boards_demo[i++] = get_wordprocessor_bplugin_info();
   static_boards_demo[i++] = NULL;
 
   gc_board_number_in_demo = i - 2;
 
   i=0;
 
-  static_boards[i++] = get_awele_bplugin_info();
   static_boards[i++] = get_advanced_colors_bplugin_info();
   static_boards[i++] = get_algebra_bplugin_info();
   static_boards[i++] = get_algebra_bplugin_info();
   static_boards[i++] = get_algebra_guesscount_bplugin_info();
+  static_boards[i++] = get_awele_bplugin_info();
   static_boards[i++] = get_canal_lock_bplugin_info();
   static_boards[i++] = get_chess_bplugin_info();
   static_boards[i++] = get_click_on_letter_bplugin_info();
@@ -145,18 +149,20 @@ void gc_board_init(void)
   static_boards[i++] = get_money_bplugin_info();
   static_boards[i++] = get_paratrooper_bplugin_info();
   static_boards[i++] = get_planegame_bplugin_info();
+  static_boards[i++] = get_python_bplugin_info();
   static_boards[i++] = get_railroad_bplugin_info();
   static_boards[i++] = get_read_colors_bplugin_info();
   static_boards[i++] = get_reading_bplugin_info();
   static_boards[i++] = get_reversecount_bplugin_info();
+  static_boards[i++] = get_scale_bplugin_info();
   static_boards[i++] = get_shapegame_bplugin_info();
   static_boards[i++] = get_smallnumbers_bplugin_info();
   static_boards[i++] = get_submarine_bplugin_info();
   static_boards[i++] = get_superbrain_bplugin_info();
   static_boards[i++] = get_target_bplugin_info();
   static_boards[i++] = get_traffic_bplugin_info();
+  static_boards[i++] = get_wordprocessor_bplugin_info();
   static_boards[i++] = get_wordsgame_bplugin_info();
-  static_boards[i++] = get_python_bplugin_info();
   static_boards[i++] = NULL;
 
   i=0;
@@ -203,7 +209,7 @@ void gc_board_set_current(GcomprisBoard * gcomprisBoard)
   bp_data->current_gcompris_board = gcomprisBoard;
 }
 
-#ifdef WIN32
+#ifdef STATIC_MODULE
 gboolean
 gc_board_check_file(GcomprisBoard *gcomprisBoard)
 {
@@ -380,6 +386,7 @@ gc_board_pause(int pause)
       if(gc_board_get_current_board_plugin()->pause_board)
 	gc_board_get_current_board_plugin()->pause_board(pause);
     }
+  else g_warning ("No boards to pause ?");
 }
 
 void
