@@ -233,7 +233,8 @@ display_file_selector(int the_mode,
 
   /* Entry area */
   widget_entry = (GtkEntry *)gtk_entry_new ();
-  gtk_entry_set_max_length(widget_entry, 30);
+  if(mode==MODE_SAVE)
+    gtk_entry_set_max_length(widget_entry, 30);
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_widget_get_type (),
 				"widget", GTK_WIDGET(widget_entry),
@@ -268,11 +269,12 @@ display_file_selector(int the_mode,
     if(mimeType) {
       result = strdup(gettext(mimeType->description));
     } else {
-      result = str;
+      result = strdup(str);
     }
 
 
     gtk_combo_box_append_text(GTK_COMBO_BOX(gtk_combo_filetypes), result);
+    g_free(result);
 
     while ( (sub_string=(char *)strtok(NULL, " ")) != NULL)
       {
@@ -281,10 +283,11 @@ display_file_selector(int the_mode,
 	if(mimeType) {
 	  result = strdup(gettext(mimeType->description));
 	} else {
-	  result = str;
+	  result = strdup(str);
 	}
 
 	gtk_combo_box_append_text(GTK_COMBO_BOX(gtk_combo_filetypes), result);
+	g_free(result);
       }
 
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
@@ -381,7 +384,7 @@ display_file_selector(int the_mode,
 
   file_selector_displayed = TRUE;
 
-  full_rootdir = g_strconcat(gc_prop_current_user_dirname_get(), "/", rootdir, NULL);
+  full_rootdir = g_strconcat(gc_prop_get()->user_dir, "/", rootdir, NULL);
   gc_util_create_rootdir(full_rootdir);
 
   current_rootdir = full_rootdir;
@@ -771,9 +774,10 @@ item_event_file_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  }
 
 	  /* DO NOT FREE RESULT OR PYTHON SIDE WILL BE IN TROUBLE */
-	  //	  if(result) {
-	  //	    g_free(result);
-	  //	  }
+	  /* ADDENDUM: DOES NOT HURT ANYMORE, WHY ? */
+	  if(result) {
+	    g_free(result);
+	  }
 	}
 	gc_selector_file_stop();
       } else if(!strcmp((char *)data, "/cancel/")) {
@@ -847,7 +851,7 @@ static void parse_doc(xmlDocPtr doc) {
 
   cur = xmlDocGetRootElement(doc);
   if (cur == NULL) {
-    fprintf(stderr,"empty document\n");
+    g_warning("empty document\n");
     xmlFreeDoc(doc);
     return;
   }
