@@ -65,7 +65,6 @@ gchar * exec_prefix = NULL;
 
 //static gint pause_board_cb (GtkWidget *widget, gpointer data);
 static void quit_cb (GtkWidget *widget, gpointer data);
-static void map_cb  (GtkWidget *widget, gpointer data);
 static gint board_widget_key_press_callback (GtkWidget   *widget,
 					    GdkEventKey *event,
 					    gpointer     client_data);
@@ -89,7 +88,6 @@ static GtkEntry *widget_activation_entry;
 
 static GcomprisProperties *properties = NULL;
 static gboolean		   antialiased = FALSE;
-static gboolean		   is_mapped = FALSE;
 
 /****************************************************************************/
 /* Some constants.  */
@@ -243,7 +241,8 @@ static struct
   int window_x;
   int window_y;
   gboolean fullscreen_active;
-} XF86VidModeData = { { 0 }, { 0 }, 0, 0, 0, 0, FALSE };
+  int ignore_focus_out;
+} XF86VidModeData = { { 0 }, { 0 }, 0, 0, 0, 0, FALSE, 0 };
 
 static void xf86_vidmode_init( void );
 static void xf86_vidmode_set_fullscreen( int state );
@@ -390,6 +389,13 @@ GtkWidget *gc_get_window()
   return window;
 }
 
+void gc_ignore_next_focus_out()
+{
+#ifdef XF86_VIDMODE
+  XF86VidModeData.ignore_focus_out++;
+#endif
+}
+
 GnomeCanvasItem *gc_set_background(GnomeCanvasGroup *parent, gchar *file)
 {
   GdkPixbuf *background_pixmap = NULL;
@@ -651,9 +657,6 @@ static void setup_window ()
   gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 		      GTK_SIGNAL_FUNC (quit_cb), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (window), "map_event",
-		      GTK_SIGNAL_FUNC (map_cb), NULL);
-
 #ifdef XF86_VIDMODE
   /* The Xf86VidMode code needs to accuratly now the window position,
      this is the only way to get it, and it needs to track the focus to
@@ -854,6 +857,9 @@ display_activation_dialog()
  */
 int gc_activation_check(char *code)
 {
+#ifdef  DISABLE_ACTIVATION_CODE
+  return 1
+#else
   int value = 0;
   int i;
   char crc1 = 0;
@@ -895,6 +901,7 @@ int gc_activation_check(char *code)
     return(1);
   else
     return(0);
+#endif
 }
 
 /* Check the activation code
@@ -971,17 +978,18 @@ void gc_fullscreen_set(gboolean state)
   else
     {
       /* The hide must be done at least for KDE */
-      if (is_mapped)
-        gtk_widget_hide (window);
+      gtk_widget_hide (window);
       gdk_window_set_decorations (window->window, GDK_DECOR_ALL);
-      if (is_mapped)
-        gtk_widget_show (window);
+      gtk_widget_show (window);
       gdk_window_set_functions (window->window, GDK_FUNC_ALL);
 #ifdef XF86_VIDMODE
       if(properties->noxf86vm)
 #endif
 	gtk_window_unfullscreen (GTK_WINDOW(window));
       gtk_widget_set_uposition (window, 0, 0);
+
+      /* Mandatory or on windows we get iconified */
+      gtk_window_deiconify (GTK_WINDOW(window));
     }
 
 }
@@ -1030,7 +1038,9 @@ static void cleanup()
 
   gc_board_stop();
   gc_db_exit();
-  gc_fullscreen_set(FALSE);
+#ifdef XF86_VIDMODE
+  xf86_vidmode_set_fullscreen(FALSE);
+#endif
   gc_menu_destroy();
   gc_prop_destroy(gc_prop_get());
   g_unlink(lock_file);
@@ -1057,20 +1067,6 @@ static void quit_cb (GtkWidget *widget, gpointer data)
   exit(0);
 }
 
-/*
- * We want GCompris to be set as fullscreen the later possible
- *
- */
-static void map_cb (GtkWidget *widget, gpointer data)
-{
-  if(is_mapped == FALSE)
-    {
-      gc_fullscreen_set(properties->fullscreen);
-      is_mapped = TRUE;
-    }
-  g_warning("gcompris window is now mapped");
-}
-
 /*
  * Process the cleanup of the child (no zombies)
  * ---------------------------------------------
@@ -1390,9 +1386,11 @@ static gint xf86_window_configured(GtkWindow *window,
 static gint xf86_focus_changed(GtkWindow *window,
   GdkEventFocus *event, gpointer param)
 {
-  if(properties->fullscreen)
-    gdk_pointer_grab(event->window, TRUE, 0, event->window, NULL,
-		     GDK_CURRENT_TIME);
+  /* printf("focus %s\n", (event->in)? "in":"out"); */
+  if (!event->in && XF86VidModeData.ignore_focus_out)
+    XF86VidModeData.ignore_focus_out--;
+  else if (properties->fullscreen)
+    xf86_vidmode_set_fullscreen(event->in);
   /* Act as if we aren't there / aren't hooked up */
   return FALSE;
 }
@@ -1482,7 +1480,14 @@ main (int argc, char *argv[])
     }
 
   /* Now we know where our config file is, load the saved config */
-  gc_prop_load(properties);
+  gc_prop_old_config_migration(properties);
+  gc_prop_load(properties, GC_PROP_FROM_USER_CONF);
+
+  /* We overwrite the user config with the administrator system config
+     It let the sysadmin to specify a certain set of value that are restaured
+     whatever the user saved
+  */
+  gc_prop_load(properties, GC_PROP_FROM_SYSTEM_CONF);
 
   /* Single instance Check */
   lock_file = g_strdup_printf("%s/%s", properties->config_dir, GC_LOCK_FILE);
@@ -1847,6 +1852,9 @@ main (int argc, char *argv[])
 
   setup_window ();
 
+  if (properties->fullscreen)
+    gc_fullscreen_set(properties->fullscreen);
+
   gtk_widget_show_all (window);
 
   /* If a specific activity is selected, skeep the intro music */
