@@ -20,8 +20,9 @@
 #include <string.h>
 
 #include "gcompris.h"
-#include <sys/stat.h>
+#include <glib/gstdio.h>
 
+static char *escape_quote(const char *input);
 
 #ifdef USE_SQLITE
 static sqlite3 *gcompris_db=NULL;
@@ -45,6 +46,8 @@ static sqlite3 *gcompris_db=NULL;
   "CREATE TABLE board_profile_conf (profile_id INT, board_id INT, conf_key TEXT, conf_value TEXT ); "
 #define CREATE_TABLE_BOARDS						\
   "CREATE TABLE boards (board_id INT UNIQUE, name TEXT, section_id INT, section TEXT, author TEXT, type TEXT, mode TEXT, difficulty INT, icon TEXT, boarddir TEXT, mandatory_sound_file TEXT, mandatory_sound_dataset TEXT, filename TEXT, title TEXT, description TEXT, prerequisite TEXT, goal TEXT, manual TEXT, credit TEXT);"
+#define CREATE_TABLE_LOGS						\
+  "CREATE TABLE logs (date TEXT, duration INT, user_id INT, board_id INT, level INT, sublevel INT, status INT, comment TEXT);"
 
 #define CREATE_TABLE_INFO						\
   "CREATE TABLE informations (gcompris_version TEXT UNIQUE, init_date TEXTUNIQUE, profile_id INT UNIQUE ); "
@@ -52,6 +55,9 @@ static sqlite3 *gcompris_db=NULL;
 #define PRAGMA_INTEGRITY			\
   "PRAGMA integrity_check; "
 
+#define PRAGMA_SCHEMA_VERSION			\
+  "PRAGMA schema_version; "
+
 /* WARNING: template for g_strdup_printf */
 #define SET_VERSION(v)							\
   "INSERT INTO informations (gcompris_version) VALUES(\'%s\'); ", v
@@ -127,12 +133,17 @@ int gc_db_init()
 
   if (!g_file_test(properties->database, G_FILE_TEST_EXISTS))
     creation = TRUE;
+
+#ifndef WIN32
+    /* this stat() does not work on WinXP */
+    /* NEEDS CHECKING IN WINXP */
+
   else {
     /* we have to check this file is not empty,
        because bug in administration */
     struct stat buf;
 
-    if (stat(properties->database, &buf)!=0)
+    if (g_stat(properties->database, &buf)!=0)
       g_error("Can't stat %s", properties->database);
 
     /* if size of file is null, we recreate the tables */
@@ -141,10 +152,11 @@ int gc_db_init()
       g_warning("Database file is empty! Trying to create table...");
     }
   }
+#endif
 
   rc = sqlite3_open(properties->database, &gcompris_db);
   if( rc ){
-    g_error("Can't open database: %s\n", sqlite3_errmsg(gcompris_db));
+    g_warning("Can't open database %s : %s\n", properties->database, sqlite3_errmsg(gcompris_db));
     sqlite3_close(gcompris_db);
     exit(1);
   }
@@ -193,6 +205,10 @@ int gc_db_init()
     if( rc!=SQLITE_OK ){
       g_error("SQL error: %s\n", zErrMsg);
     }
+    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_LOGS, NULL,  0, &zErrMsg);
+    if( rc!=SQLITE_OK ){
+      g_error("SQL error: %s\n", zErrMsg);
+    }
 
     /* CREATE TRIGGERS */
     rc = sqlite3_exec(gcompris_db,TRIGGER_DELETE_CLASS, NULL,  0, &zErrMsg);
@@ -277,8 +293,10 @@ int gc_db_init()
     if( rc!=SQLITE_OK ){
       g_error("SQL error: %s\n", zErrMsg);
     }
+
     if (!(strcmp(result[1],"ok")==0))
       g_error("DATABASE integrity check returns %s \n", result[1]);
+
     g_warning("Database Integrity ok");
     sqlite3_free_table(result);
 
@@ -294,8 +312,31 @@ int gc_db_init()
     }
 
     if (strcmp(result[1],VERSION)!=0)
-      g_warning("Running GCompris is %s, but databse vrsion is %s", VERSION, result[1]);
+      g_warning("Running GCompris is %s, but database version is %s", VERSION, result[1]);
     sqlite3_free_table(result);
+
+    /* Schema upgrade */
+    rc = sqlite3_get_table(gcompris_db,
+			   PRAGMA_SCHEMA_VERSION,
+			   &result,
+			   &nrow,
+			   &ncolumn,
+			   &zErrMsg
+			   );
+    if( rc!=SQLITE_OK ){
+      g_error("SQL error: %s\n", zErrMsg);
+    }
+
+    int version = atoi(result[1]);
+    sqlite3_free_table(result);
+    if(version <= 16)
+      {
+	g_warning("Upgrading from <16 schema version\n");
+	rc = sqlite3_exec(gcompris_db,CREATE_TABLE_LOGS, NULL,  0, &zErrMsg);
+	if( rc!=SQLITE_OK ) {
+	  g_error("SQL error: %s\n", zErrMsg);
+	}
+      }
   }
 
   return TRUE;
@@ -411,10 +452,10 @@ gboolean gc_db_check_boards()
 }
 
 
-#define BOARD_INSERT							\
+#define GC_BOARD_INSERT							\
   "INSERT OR REPLACE INTO boards VALUES (%d, %Q, %d, %Q, %Q, %Q, %Q, %d, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q);"
 
-#define MAX_BOARD_ID				\
+#define MAX_GC_BOARD_ID				\
   "SELECT MAX(board_id) FROM boards;"
 
 #define SECTION_ID(s)						\
@@ -489,7 +530,7 @@ gc_db_board_update(guint *board_id,
 
       /* get last board_id written */
       rc = sqlite3_get_table(gcompris_db,
-			     MAX_BOARD_ID,
+			     MAX_GC_BOARD_ID,
 			     &result,
 			     &nrow,
 			     &ncolumn,
@@ -555,7 +596,7 @@ gc_db_board_update(guint *board_id,
     sqlite3_free_table(result);
   }
 
-  request = sqlite3_mprintf( BOARD_INSERT,
+  request = sqlite3_mprintf( GC_BOARD_INSERT,
 			     *board_id,
 			     name,
 			     *section_id,
@@ -689,7 +730,7 @@ GList *gc_db_read_board_from_section(gchar *section)
 }
 
 
-#define BOARD_ID_READ				\
+#define GC_BOARD_ID_READ				\
   "SELECT board_id FROM boards;"
 
 GList *gc_db_get_board_id(GList *list)
@@ -706,7 +747,7 @@ GList *gc_db_get_board_id(GList *list)
   int i;
 
   rc = sqlite3_get_table(gcompris_db,
-			 BOARD_ID_READ,
+			 GC_BOARD_ID_READ,
 			 &result,
 			 &nrow,
 			 &ncolumn,
@@ -1871,3 +1912,59 @@ int gc_db_is_activity_in_profile(GcomprisProfile *profile, char *activity_name)
   return TRUE;
 #endif
 }
+
+/** \brief insert a new log in the database
+ *
+ */
+void gc_db_log(gchar *date, int duration,
+	       int user_id, int board_id,
+	       int level, int sublevel,
+	       int status, gchar *comment)
+{
+#ifdef USE_SQLITE
+  char *zErrMsg;
+  int rc;
+  gchar *request;
+  gchar *comment_quoted = escape_quote(comment);
+
+  request = g_strdup_printf("INSERT INTO logs (date, duration, user_id, board_id, level, sublevel, status, comment)"
+			    "VALUES ( \'%s\', %d,  %d,  %d,  %d,  %d,  %d,  \'%s\');",
+			    date, duration, user_id, board_id, level, sublevel, status, comment_quoted);
+
+  rc = sqlite3_exec(gcompris_db, request, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+
+  if(comment)
+    g_free(comment_quoted);
+#endif
+}
+
+/* \brief SQL Requires single ' to be replaced by ''
+ *
+ */
+static char *
+escape_quote(const char *input)
+{
+  gsize size = strlen(input)*2+1; /* 2 is the most increase we can get */
+  gchar *result = g_malloc(size);
+  int i;
+  int o = 0;
+
+  result[0] = '\0';
+
+  for(i = 0; i < strlen(input); i++)
+    {
+      char c = input[i];
+      if(c == '\'')
+	o = g_strlcat(result, "''", size);
+      else
+	{
+	  result[o++] = c;
+	  result[o+1] = '\0';
+	}
+    }
+  return result;
+}
+
