@@ -188,7 +188,7 @@ gc_prop_new ()
   return (tmp);
 }
 
-void old_config_migration(GcomprisProperties *props)
+void gc_prop_old_config_migration(GcomprisProperties *props)
 {
   char *old;
   char *new;
@@ -336,9 +336,9 @@ void old_config_migration(GcomprisProperties *props)
 
 
 void
-gc_prop_load (GcomprisProperties *props)
+gc_prop_load (GcomprisProperties *props, GCPropSourceConf source_conf)
 {
-  char          *config_file;
+  char          *config_file = NULL;
   GScanner      *scanner;
   gchar		*content;
   gsize		length;
@@ -346,9 +346,15 @@ gc_prop_load (GcomprisProperties *props)
   const gchar   *locale;
 #endif
 
-  config_file = g_strconcat(props->config_dir, "/", gc_prop_config_file_get(), NULL);
-
-  old_config_migration(props);
+  switch(source_conf)
+    {
+    case GC_PROP_FROM_SYSTEM_CONF:
+      config_file = g_strconcat(SYSTEM_CONFIG_DIR, "/", gc_prop_config_file_get(), NULL);
+      break;
+    case GC_PROP_FROM_USER_CONF:
+      config_file = g_strconcat(props->config_dir, "/", gc_prop_config_file_get(), NULL);
+      break;
+    }
 
   if(g_file_get_contents(config_file,
 			 &content,
@@ -406,10 +412,20 @@ gc_prop_load (GcomprisProperties *props)
 	  if(!scan_get_int(scanner, &props->filter_style))
 	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "skin")) {
-        g_free(props->skin);
+	  g_free(props->skin);
 	  props->skin = scan_get_string(scanner);
 	  if(!props->skin)
 	    g_warning("Config file parsing error on token %s", token);
+	} else if(!strcmp(value.v_identifier, "user_dir")) {
+	  g_free(props->user_dir);
+	  props->user_dir = scan_get_string(scanner);
+	  if(!props->user_dir)
+	    g_warning("Config file parsing error on token %s", token);
+	} else if(!strcmp(value.v_identifier, "config_dir")) {
+	  g_free(props->config_dir);
+	  props->config_dir = scan_get_string(scanner);
+	  if(!props->config_dir)
+	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "locale")) {
 	  props->locale = scan_get_string(scanner);
 	  if(!props->locale)
